//----< depMatrix.h > ---------------------------------------------
//---- Author: Qiang Zheng ------------------------------------------
//
//---- Purpose: To use an adjecent matrix to express the file dependecies
//----          And to maintain this matrix.
//----          And an assotiative array is used to associate the filename
//----          and the index of the row of the matrix.
//
//---- e.g. file1.cpp-->file2.h--> 
//            |                  |
//  	       -------->file3.h---->file4.h  (Here "-->" means "is dependent on")
//
//---- The corresponding adjecent matrix is:
//---- (T,T,T,T
//----  F,T,F,T
//----  F,F,F,T
//----  F,F,F,T)
//
//---- In this array, say dependence, dependence[i][j] = T,<==> file i depends on file j, 
//---- Attention: A file is defined to be dependent on itself
//
//---- And in the associative array fileNames[], fileNames[0] = "file1.cpp",
//---- fileNames[1] = "file2.h"; fileNames[2] = "file3.h", fileName[3] = "file4.h";

#include<vector>
#include <iostream>		// cout, <<

class depMatrix {
public:
	// constructors and destructor
	depMatrix();
	depMatrix(int);
	~depMatrix();

	//return the number of the files in the matrix
	int getCurFileNum();

	// add a file to the matrix and adjust the dependece matrix.
	void addFile(const vector);

	//display the files being included by the file specified by the argument
	void displayDepFiles(char*);

	//return file name according to the index
	char* getFileName(int);

	//return the index of a file in the dependence matrix
	int indexOf(char*);

protected:
	int size;		//the size of the matrix is (size * size);
	int fileNum;	//current number of the files being put into this matrix
	bool dependence[40][40];	//the adjecent matrix to represent the dependece relation
	char* fileNames[40];

	void resize(int);			// Resize the matrix and the fileNames array
	void dislayDepFiles(int);	// Display files being included by the file specified by index
}